abacusai.api_class.python_functions — AbacusAI documentation

# abacusai.api_class.python_functions

## Classes

`PythonFunctionArgument` | A config class for python function arguments
`OutputVariableMapping` | A config class for python function arguments

## Module Contents

class abacusai.api_class.python_functions.PythonFunctionArgument

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for python function arguments

  Parameters:

    - variable_type (PythonFunctionArgumentType) – The type of the python function argument

    - name (str) – The name of the python function variable

    - is_required (bool) – Whether the argument is required

    - value (Any) – The value of the argument

    - pipeline_variable (str) – The name of the pipeline variable to use as the value

  variable_type: abacusai.api_class.enums.PythonFunctionArgumentType
  name: str
  is_required: bool
  value: Any
  pipeline_variable: str

class abacusai.api_class.python_functions.OutputVariableMapping

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for python function arguments

  Parameters:

    - variable_type (PythonFunctionOutputArgumentType) – The type of the python function output argument

    - name (str) – The name of the python function variable

  variable_type: abacusai.api_class.enums.PythonFunctionOutputArgumentType
  name: str